@@ -56,11 +56,46 @@ move_bucket_to_host <- function(url, bucket) {
   return(url)
 }
 
+# Check if a given bucket name is an S3 access point.
+is_access_point <- function(bucket_name) {
+  regex <- "^(.+):(.+):(.+):(.+):(.+):(.+)$"
+  return(grepl(regex, bucket_name))
+}
+
+# Parse the S3 access point ARN and return the corresponding endpoint.
+# See https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-access-points.html
+#
+# ARN format: arn:aws:s3:{region}:{account-id}:accesspoint/{accesspoint-name}
+# Access point endpoint format: {accesspoint-name}-{account-id}.s3-accesspoint.{region}.{dns-suffix}
+# Example:
+#   In: arn:aws:s3:us-west-2:123456789012:accesspoint/test
+#   Out: test-123456789012.s3-accesspoint.us-west-2.amazonaws.com
+get_access_point_endpoint <- function(access_point) {
+  part <- strsplit(access_point, ":|/")[[1]]
+  region <- part[4]
+  account <- part[5]
+  name <- part[7]
+  endpoint <- sprintf("%s-%s.s3-accesspoint.%s.amazonaws.com", name, account, region)
+  return(endpoint)
+}
+
+remove_bucket_from_url <- function(url) {
+  url$path <- gsub("\\{Bucket+?\\}", "", url$path)
+  if (url$path == "") url$path <- "/"
+  return(url)
+}
+
 update_endpoint_for_s3_config <- function(request) {
   bucket_name <- bucket_name_from_req_params(request)
 
   if (is.null(bucket_name)) return(request)
 
+  if (is_access_point(bucket_name)) {
+    request$http_request$url$host <- get_access_point_endpoint(bucket_name)
+    request$http_request$url <- remove_bucket_from_url(request$http_request$url)
+    return(request)
+  }
+
   if (!host_compatible_bucket_name(bucket_name)) return(request)
 
   if (request$operation$name %in% c("GetBucketLocation")) return(request)
