@@ -96,7 +96,7 @@ xml_build_structure <- function(params) {
 
     parsed <- xml_build(child)
 
-    if (length(parsed) > 0) {
+    if (!is_empty(parsed)) {
       location_name <- tag_get(child, "locationName")
       if (location_name == "") location_name <- name
 
